# api-FISH



## Installation

### Dependencies

apiFISH requires Python XXX or newer. Additionally, it has the following dependencies:

- numpy (>= 1.16.0)
- scipy (>= 1.4.1)
- scikit-learn (>= 0.21.0)
- scikit-image (>= 0.14.2)
- matplotlib (>= 3.0.2)
- pandas (>= 0.24.0)
- mrc (>= 0.1.5)

- tensorflow (== 2.3.0)
- tensorflow-addons (== 0.12.1)

### Virtual environment



## Usage



## Support



## Roadmap (suggestion)



## Development



### Source code



### Contributing



### Testing



## Citation

> 
